# SOME DESCRIPTIVE TITLE.
# Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
# This file is distributed under the same license as the PACKAGE package.
# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
#
#, fuzzy
msgid ""
msgstr ""
"Project-Id-Version: PACKAGE VERSION\n"
"Report-Msgid-Bugs-To: \n"
"POT-Creation-Date: 2009-08-16 07:57+0900\n"
"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: LANGUAGE <LL@li.org>\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=CHARSET\n"
"Content-Transfer-Encoding: 8bit\n"

#: src/cellrenderercolor.c:159 src/cellrenderercolor.c:160 src/preference.c:81
msgid "Color"
msgstr ""

#: src/cellrendererebook.c:161 src/mainwindow.c:985
msgid "Text"
msgstr ""

#: src/cellrendererebook.c:162
msgid "Text to render"
msgstr ""

#: src/cellrendererebook.c:170
msgid "BookInfo"
msgstr ""

#: src/cellrendererebook.c:171
msgid "Book Information"
msgstr ""

#: src/dictbar.c:202
msgid "Push to enable this dictionary."
msgstr ""

#: src/dictbar.c:325
msgid "Select dictionary group."
msgstr ""

#: src/dump.c:217 src/dump.c:356
msgid "Close"
msgstr ""

#: src/dump.c:229 src/dump.c:367
msgid "page"
msgstr ""

#: src/dump.c:376
msgid "offset"
msgstr ""

#: src/eb.c:375 src/eb.c:442 src/mainmenu.c:478 src/mainwindow.c:482
#: src/mainwindow.c:1138
msgid "Automatic Search"
msgstr ""

#: src/eb.c:380 src/eb.c:446 src/mainmenu.c:486 src/mainwindow.c:1149
msgid "Exactword Search"
msgstr ""

#: src/eb.c:386 src/eb.c:450 src/mainmenu.c:492 src/mainwindow.c:1161
msgid "Forward Search"
msgstr ""

#: src/eb.c:392 src/eb.c:454 src/mainmenu.c:499 src/mainwindow.c:1173
msgid "Backward Search"
msgstr ""

#: src/eb.c:398 src/eb.c:458 src/mainmenu.c:506 src/mainwindow.c:1185
msgid "Keyword Search"
msgstr ""

#: src/eb.c:404 src/eb.c:462 src/mainmenu.c:513 src/mainwindow.c:490
#: src/mainwindow.c:491 src/mainwindow.c:1197
msgid "Multiword Search"
msgstr ""

#: src/eb.c:423 src/eb.c:476
msgid "Full Text Search"
msgstr ""

#: src/eb.c:427 src/eb.c:480 src/mainmenu.c:547 src/mainwindow.c:481
#: src/mainwindow.c:499 src/mainwindow.c:500 src/mainwindow.c:1224
#: src/preference.c:94
msgid "Internet Search"
msgstr ""

#: src/eb.c:431 src/eb.c:484 src/grep.c:77 src/mainmenu.c:554
#: src/mainwindow.c:507 src/mainwindow.c:508 src/mainwindow.c:1238
#: src/preference.c:88
msgid "File Search"
msgstr ""

#. Cancelable
#. Non-cancelable
#: src/eb.c:1617 src/eb.c:1621
msgid "Fulltext search"
msgstr ""

#: src/ebview.c:109
msgid "Failed to execute command. Please check setting."
msgstr ""

#: src/external.c:208
msgid "Web browser not set"
msgstr ""

#. Create file list
#: src/grep.c:442
msgid "Listing files..."
msgstr ""

#: src/grep.c:456 src/grep.c:1018 src/grep.c:1155 src/grep.c:1182
#: src/pref_io.c:1575 src/shortcutfunc.c:85 src/shortcutfunc.c:113
#: src/shortcutfunc.c:189 src/shortcutfunc.c:234
msgid "Manual Select"
msgstr ""

#: src/grep.c:545
msgid "done\n"
msgstr ""

#: src/grep.c:555
msgid "Force ordinary text.\n"
msgstr ""

#: src/grep.c:560
msgid "Seems like regular expression.\n"
msgstr ""

#: src/grep.c:567
msgid "Force regular expression.\n"
msgstr ""

#: src/grep.c:572
msgid "Seems like ordinary text.\n"
msgstr ""

#: src/grep.c:601
msgid "Failed to compile pattern.\n"
msgstr ""

#: src/grep.c:608
msgid ""
"\n"
"Searching following files...\n"
msgstr ""

#: src/grep.c:655
msgid ""
"\n"
"File search completed.\n"
msgstr ""

#: src/grep.c:1113
msgid "Suppress Hidden Files"
msgstr ""

#: src/grep.c:1119
msgid "Suppress files whose name start with dot."
msgstr ""

#: src/grep.c:1121
msgid "Ignore Case"
msgstr ""

#: src/grep.c:1127
msgid ""
"When checked, uppercase letters and lowercase letters are regarded as "
"identical."
msgstr ""

#: src/headword.c:776
msgid "Go to previous hit list."
msgstr ""

#: src/headword.c:795
msgid "Go to next hit list."
msgstr ""

#: src/mainmenu.c:520 src/mainwindow.c:1209
msgid "Fulltext Search"
msgstr ""

#: src/mainmenu.c:530
msgid "Menu"
msgstr ""

#: src/mainmenu.c:537
msgid "Copyright"
msgstr ""

#: src/mainmenu.c:593
msgid "Exit"
msgstr ""

#: src/mainmenu.c:598
msgid "File"
msgstr ""

#: src/mainmenu.c:606
msgid "Show/Hide"
msgstr ""

#: src/mainmenu.c:613
msgid "Menu Bar"
msgstr ""

#: src/mainmenu.c:622
msgid "Dictionary Selection Bar"
msgstr ""

#: src/mainmenu.c:631
msgid "Status Bar"
msgstr ""

#: src/mainmenu.c:638
msgid "Tree Pane Tab"
msgstr ""

#: src/mainmenu.c:649
msgid "Contents"
msgstr ""

#: src/mainmenu.c:656
msgid "Emphasize Keyword"
msgstr ""

#: src/mainmenu.c:664
msgid "Show Image Inline"
msgstr ""

#. text size
#: src/mainmenu.c:678 src/pref_shortcut.c:103
msgid "Increase Font Size"
msgstr ""

#: src/mainmenu.c:684 src/pref_shortcut.c:104
msgid "Decrease Font Size"
msgstr ""

#. Space between lines
#: src/mainmenu.c:695 src/pref_shortcut.c:105
msgid "Expand Lines"
msgstr ""

#: src/mainmenu.c:701 src/pref_shortcut.c:106
msgid "Shrink Lines"
msgstr ""

#. Result list
#: src/mainmenu.c:709
msgid "Result List"
msgstr ""

#. Sort by dictionary.
#: src/mainmenu.c:716
msgid "Sort By Dictionary"
msgstr ""

#. Show filename
#: src/mainmenu.c:725
msgid "Show Filename"
msgstr ""

#. Pane direction
#: src/mainmenu.c:740
msgid "Pane Direction"
msgstr ""

#: src/mainmenu.c:749
msgid "Horizontal"
msgstr ""

#: src/mainmenu.c:762
msgid "Vertical"
msgstr ""

#. Tab position
#: src/mainmenu.c:778
msgid "Tab Position"
msgstr ""

#: src/mainmenu.c:786
msgid "Top"
msgstr ""

#: src/mainmenu.c:796
msgid "Bottom"
msgstr ""

#: src/mainmenu.c:806
msgid "Left"
msgstr ""

#: src/mainmenu.c:816
msgid "Right"
msgstr ""

#: src/mainmenu.c:826
msgid "View"
msgstr ""

#: src/mainmenu.c:834
msgid "Search Method"
msgstr ""

#: src/mainmenu.c:841
msgid "Tools"
msgstr ""

#.
#. item = gtk_menu_item_new_with_label(_("Add/Remove Dictionary"));
#. gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
#. g_signal_connect(G_OBJECT(item), "activate",
#. G_CALLBACK(menuitem_handler),
#. (gpointer)"pref.dict");
#.
#. item = gtk_menu_item_new_with_label(_("Stemming"));
#. gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
#. g_signal_connect(G_OBJECT(item), "activate",
#. G_CALLBACK(menuitem_handler),
#. (gpointer)"pref.ending");
#.
#. item = gtk_menu_item_new_with_label(_("Shortcut"));
#. gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
#. g_signal_connect(G_OBJECT(item), "activate",
#. G_CALLBACK(menuitem_handler),
#. (gpointer)"pref.shortcut");
#.
#. item = gtk_menu_item_new_with_label(_("Search Engines"));
#. gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
#. g_signal_connect(G_OBJECT(item), "activate",
#. G_CALLBACK(menuitem_handler),
#. (gpointer)"pref.web");
#.
#. item = gtk_menu_item_new_with_label(_("External Program"));
#. gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
#. g_signal_connect(G_OBJECT(item), "activate",
#. G_CALLBACK(menuitem_handler),
#. (gpointer)"pref.external");
#.
#. item = gtk_menu_item_new_with_label(_("Font"));
#. gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
#. g_signal_connect(G_OBJECT(item), "activate",
#. G_CALLBACK(menuitem_handler),
#. (gpointer)"pref.font");
#.
#. item = gtk_menu_item_new_with_label(_("Color"));
#. gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
#. g_signal_connect(G_OBJECT(item), "activate",
#. G_CALLBACK(menuitem_handler),
#. (gpointer)"pref.color");
#.
#. item = gtk_menu_item_new_with_label(_("Misc"));
#. gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
#. g_signal_connect(G_OBJECT(item), "activate",
#. G_CALLBACK(menuitem_handler),
#. (gpointer)"pref.misc");
#.
#.
#. Selection search
#: src/mainmenu.c:896 src/preference.c:85
msgid "Selection"
msgstr ""

#: src/mainmenu.c:904
msgid "Do Nothing"
msgstr ""

#: src/mainmenu.c:914
msgid "Copy Only"
msgstr ""

#: src/mainmenu.c:924
msgid "Search In Main Window"
msgstr ""

#: src/mainmenu.c:934
msgid "Search In Main Window + Top"
msgstr ""

#: src/mainmenu.c:944
msgid "Search In Popup"
msgstr ""

#. if(selection_mode == SELECTION_POPUP)
#. gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), TRUE);
#. Dump
#: src/mainmenu.c:954
msgid "Dump"
msgstr ""

#: src/mainmenu.c:961
msgid "Hex Dump"
msgstr ""

#: src/mainmenu.c:967
msgid "Text Dump"
msgstr ""

#. Option
#: src/mainmenu.c:978
msgid "Options..."
msgstr ""

#: src/mainmenu.c:988
msgid "Usage"
msgstr ""

#: src/mainmenu.c:994
msgid "Show EBView Home"
msgstr ""

#: src/mainmenu.c:1000
msgid "About"
msgstr ""

#: src/mainmenu.c:1007
msgid "Help"
msgstr ""

#: src/mainwindow.c:101 src/websearch.c:108
msgid "Please enter search word."
msgstr ""

#: src/mainwindow.c:118 src/selection.c:169 src/textview.c:84
#: src/thread_search.c:64 src/thread_search.c:150
msgid "No hit."
msgstr ""

#: src/mainwindow.c:302 src/misc.c:146
#, c-format
msgid "Couldn't find %s. Check installation."
msgstr ""

#: src/mainwindow.c:341
msgid "Help will be shown in external web browser."
msgstr ""

#: src/mainwindow.c:748
msgid "Search Word"
msgstr ""

#: src/mainwindow.c:768
msgid ""
"Type word here. You can type multiple space-separated words for keyword "
"search. For file search, specify words or regular expression."
msgstr ""

#: src/mainwindow.c:784 src/multi.c:294
msgid "Start search"
msgstr ""

#: src/mainwindow.c:810
msgid "Select search method."
msgstr ""

#: src/mainwindow.c:836
msgid "When enabled, X selection is searched automatically"
msgstr ""

#: src/mainwindow.c:854
msgid ""
"When enabled, result of X selection search will be shown in popup window"
msgstr ""

#: src/mainwindow.c:870
msgid "Previous Item"
msgstr ""

#: src/mainwindow.c:882
msgid "Next Item"
msgstr ""

#: src/mainwindow.c:897
msgid "show next in history"
msgstr ""

#: src/mainwindow.c:908
msgid "show previous in history"
msgstr ""

#: src/mainwindow.c:994
msgid "Candidate"
msgstr ""

#. rp->heading = strdup(_("menu"));
#: src/menu.c:70
msgid "menu"
msgstr ""

#. rp->heading = strdup(_("copyright"));
#: src/menu.c:130
msgid "copyright"
msgstr ""

#: src/misc.c:160
#, c-format
msgid "Couldn't open %s. Check installation."
msgstr ""

#: src/multi.c:241 src/pref_color.c:238
msgid "Keyword"
msgstr ""

#: src/multi.c:283 src/multi.c:303
msgid "Candidates"
msgstr ""

#: src/pref_color.c:95 src/pref_dictgroup.c:1160
msgid "Choose Color"
msgstr ""

#: src/pref_color.c:220
msgid "Link"
msgstr ""

#: src/pref_color.c:230 src/pref_color.c:248 src/pref_color.c:266
#: src/pref_color.c:283 src/pref_color.c:301 src/pref_color.c:321
#: src/pref_font.c:176 src/pref_font.c:193 src/pref_font.c:210
#: src/pref_font.c:227
msgid "Choose"
msgstr ""

#: src/pref_color.c:256
msgid "Sound"
msgstr ""

#: src/pref_color.c:272
msgid "Movie"
msgstr ""

#: src/pref_color.c:290
msgid "Emphasis"
msgstr ""

#: src/pref_color.c:310
msgid "Reverse Background"
msgstr ""

#: src/pref_dictgroup.c:148 src/pref_dirgroup.c:132 src/pref_weblist.c:201
msgid "Please select group."
msgstr ""

#: src/pref_dictgroup.c:163 src/pref_dictgroup.c:315
msgid "Failed to load dictionary."
msgstr ""

#: src/pref_dictgroup.c:383 src/pref_dictgroup.c:503 src/pref_weblist.c:75
#: src/pref_weblist.c:111
msgid "Please select dictionary."
msgstr ""

#: src/pref_dictgroup.c:689
msgid "Failed to get subbook directory."
msgstr ""

#: src/pref_dictgroup.c:698
msgid "Failed to get title."
msgstr ""

#: src/pref_dictgroup.c:721
msgid "Failed to load book."
msgstr ""

#: src/pref_dictgroup.c:847
msgid "Please enter directory name"
msgstr ""

#: src/pref_dictgroup.c:899
msgid "Please specify title."
msgstr ""

#: src/pref_dictgroup.c:905
msgid "Please specify book path."
msgstr ""

#: src/pref_dictgroup.c:915
msgid "Subbook number incorrect."
msgstr ""

#: src/pref_dictgroup.c:1070 src/pref_dictgroup.c:1072
#: src/pref_dictgroup.c:1075 src/pref_dictgroup.c:1077
#: src/pref_dictgroup.c:1123 src/pref_dictgroup.c:1125
#: src/pref_dictgroup.c:1128 src/pref_dictgroup.c:1130
#: src/pref_dictgroup.c:1200 src/pref_dictgroup.c:1525
#, c-format
msgid "Sample"
msgstr ""

#: src/pref_dictgroup.c:1286 src/pref_dictgroup.c:1475 src/pref_dirgroup.c:315
#: src/pref_weblist.c:535
msgid "Name"
msgstr ""

#: src/pref_dictgroup.c:1388 src/pref_weblist.c:480
msgid "Group name"
msgstr ""

#: src/pref_dictgroup.c:1398 src/pref_dirgroup.c:355 src/pref_grep.c:285
#: src/pref_shortcut.c:441 src/pref_shortcut.c:533 src/pref_stemming.c:232
#: src/pref_weblist.c:488 src/pref_weblist.c:613
msgid "Add"
msgstr ""

#: src/pref_dictgroup.c:1405 src/pref_dirgroup.c:368 src/pref_grep.c:292
#: src/pref_shortcut.c:422 src/pref_stemming.c:239 src/pref_weblist.c:499
msgid "Remove"
msgstr ""

#: src/pref_dictgroup.c:1412 src/pref_weblist.c:506
msgid "Up"
msgstr ""

#: src/pref_dictgroup.c:1418 src/pref_weblist.c:512
msgid "Down"
msgstr ""

#: src/pref_dictgroup.c:1429 src/pref_dictgroup.c:1483
msgid "Path"
msgstr ""

#: src/pref_dictgroup.c:1439
msgid "Depth"
msgstr ""

#: src/pref_dictgroup.c:1453
msgid "Specify search depth. 0 means to search only specified directory."
msgstr ""

#: src/pref_dictgroup.c:1457
msgid "Search Disk"
msgstr ""

#: src/pref_dictgroup.c:1493
msgid "Subbook Number"
msgstr ""

#: src/pref_dictgroup.c:1503
msgid "Appendix Path"
msgstr ""

#: src/pref_dictgroup.c:1511
msgid "Appendix Subbook Number"
msgstr ""

#: src/pref_dictgroup.c:1530
msgid "FG"
msgstr ""

#: src/pref_dictgroup.c:1536
msgid "BG"
msgstr ""

#: src/pref_dictgroup.c:1542
msgid "Clear"
msgstr ""

#: src/pref_dirgroup.c:209
msgid "Select directory"
msgstr ""

#: src/pref_dirgroup.c:261
msgid "Directory group list"
msgstr ""

#: src/pref_dirgroup.c:308
msgid "Detail"
msgstr ""

#: src/pref_dirgroup.c:323
msgid "Enter the name of directory group."
msgstr ""

#: src/pref_dirgroup.c:325
msgid "Directory list"
msgstr ""

#: src/pref_dirgroup.c:345
msgid ""
"Specify directory names one per line. You can specify extension of files "
"that will be searched. For example, \"/some/dir/name,.txt\" searches all "
"files under /some/dir/name which have the extension .txt."
msgstr ""

#: src/pref_dirgroup.c:361
msgid "Change"
msgstr ""

#: src/pref_dirgroup.c:375
msgid "Choose.."
msgstr ""

#. gtk_container_add(GTK_CONTAINER(frame), vbox);
#: src/pref_external.c:80
msgid "Play sound internally"
msgstr ""

#: src/pref_external.c:84
msgid "Use internal routine to play sound. Valid only on windows."
msgstr ""

#: src/pref_external.c:94
msgid "Command to play sound "
msgstr ""

#: src/pref_external.c:106
#, c-format
msgid ""
"External command to play WAVE sound. %f will be replaced by data file name."
msgstr ""

#: src/pref_external.c:116
msgid "Command to play movie "
msgstr ""

#: src/pref_external.c:128
#, c-format
msgid ""
"External command to play MPEG movie. %f will be replaced by data file name."
msgstr ""

#: src/pref_external.c:138
msgid "Command to launch web browser "
msgstr ""

#: src/pref_external.c:150
#, c-format
msgid "External command to launch Web browser. %f will be replaced by URL."
msgstr ""

#: src/pref_external.c:161
msgid "Standard command to open file "
msgstr ""

#: src/pref_external.c:173
msgid ""
"Standard command to open file. %f will be replaced by filename, %l by line "
"number."
msgstr ""

#: src/pref_font.c:166 src/pref_stemming.c:281
msgid "Normal"
msgstr ""

#: src/pref_font.c:183
msgid "Bold"
msgstr ""

#: src/pref_font.c:200
msgid "Italic"
msgstr ""

#: src/pref_font.c:216
msgid "Superscript"
msgstr ""

#: src/pref_grep.c:132
msgid "Additional Lines To Display"
msgstr ""

#: src/pref_grep.c:150
msgid ""
"In addition to matched line, additional lines will be shown in contents."
msgstr ""

#: src/pref_grep.c:157
msgid "Additional Chars To Display"
msgstr ""

#: src/pref_grep.c:176
msgid ""
"When matched line is too long, several characters around keyword will be "
"shown in heading."
msgstr ""

#: src/pref_grep.c:239
msgid "Extension"
msgstr ""

#: src/pref_grep.c:250
msgid "Filter Command"
msgstr ""

#: src/pref_grep.c:261
msgid "Open Command"
msgstr ""

#: src/pref_grep.c:387
msgid "Maximum Cache Size (MB)"
msgstr ""

#: src/pref_grep.c:406
msgid "Specify maximum cache size in MB."
msgstr ""

#: src/pref_grep.c:408
msgid "Clear Cache"
msgstr ""

#: src/pref_gui.c:75
msgid "Maximum words in history"
msgstr ""

#: src/pref_gui.c:94
msgid "Maximum number of words to remember in word history"
msgstr ""

#: src/pref_gui.c:103
msgid "Chars in dictionary bar"
msgstr ""

#: src/pref_gui.c:122
msgid ""
"Specify the number of characters to display on top of each toggle buttons in "
"dictionary bar."
msgstr ""

#: src/pref_gui.c:126
msgid "Show splash screen"
msgstr ""

#: src/pref_gui.c:128
msgid "Show splash screen on loading."
msgstr ""

#: src/pref_gui.c:136
msgid "Calculate heading automatically"
msgstr ""

#: src/pref_gui.c:138
msgid "Calculate the number of cells in heading list to suit the window size."
msgstr ""

#: src/pref_gui.c:152
msgid "Maximum hits to display"
msgstr ""

#: src/pref_gui.c:171
msgid ""
"Maximum number of hits to be displayed at once.\n"
"You can go forward and backward using buttons. Valid only if automatic "
"calculation is disabled."
msgstr ""

#.
#: src/pref_gui.c:174
msgid "Enable dictionary button color"
msgstr ""

#: src/pref_gui.c:176
msgid "Enable background color of dictionary button."
msgstr ""

#: src/pref_io.c:124
msgid "Couldn't open preference. Will use default value."
msgstr ""

#: src/pref_io.c:130 src/pref_io.c:138 src/pref_io.c:269 src/pref_io.c:277
#: src/pref_io.c:284 src/pref_io.c:299 src/pref_io.c:336 src/pref_io.c:539
#: src/pref_io.c:548 src/pref_io.c:555 src/pref_io.c:573 src/pref_io.c:637
#: src/pref_io.c:646 src/pref_io.c:653 src/pref_io.c:670 src/pref_io.c:844
#: src/pref_io.c:853 src/pref_io.c:861 src/pref_io.c:875 src/pref_io.c:898
#: src/pref_io.c:906 src/pref_io.c:1079 src/pref_io.c:1087 src/pref_io.c:1094
#: src/pref_io.c:1111 src/pref_io.c:1263 src/pref_io.c:1271 src/pref_io.c:1281
#: src/pref_io.c:1349 src/pref_io.c:1357 src/pref_io.c:1367 src/pref_io.c:1412
#: src/pref_io.c:1420 src/pref_io.c:1427 src/pref_io.c:1447 src/pref_io.c:1640
#: src/pref_io.c:1649 src/pref_io.c:1658 src/pref_io.c:1675
#, c-format
msgid "Failed to parse %s. Check contents."
msgstr ""

#: src/pref_search.c:66
msgid "Maximum hits to search"
msgstr ""

#: src/pref_search.c:84
msgid ""
"Maximum number of hits to be searched.\n"
"If you increase this number, it takes time to search."
msgstr ""

#: src/pref_search.c:87
msgid "Perform word search in automatic search"
msgstr ""

#: src/pref_search.c:89
msgid "Perform word search in automatic search."
msgstr ""

#: src/pref_selection.c:72
msgid "Lookup interval (ms)"
msgstr ""

#: src/pref_selection.c:91
msgid ""
"Interval to check selection. \n"
"Increasing this number may eat up your CPU.\n"
"Ignored on Windows."
msgstr ""

#: src/pref_selection.c:99
msgid "Minimum chars for selection lookup"
msgstr ""

#: src/pref_selection.c:120
msgid ""
"When the number of characters in selection is less than this number, it will "
"not be looked up."
msgstr ""

#. gtk_box_pack_start (GTK_BOX(vbox)
#. , hbox,FALSE, FALSE, 0);
#: src/pref_selection.c:130
msgid "Maximum chars for automatic lookup"
msgstr ""

#: src/pref_selection.c:151
msgid ""
"When the number of characters in selection is larger than this number, it "
"will not be looked up."
msgstr ""

#. gtk_box_pack_start (GTK_BOX(vbox)
#. , hbox,FALSE, FALSE, 0);
#: src/pref_selection.c:161
msgid "Popup window size"
msgstr ""

#.
#. hbox = gtk_hbox_new(FALSE,10);
#. gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);
#. gtk_box_pack_start (GTK_BOX(vbox)
#. , hbox,FALSE, FALSE, 0);
#.
#: src/pref_selection.c:213
msgid "Show popup title"
msgstr ""

#: src/pref_selection.c:215
msgid "Show title of popup window."
msgstr ""

#.
#. hbox = gtk_hbox_new(FALSE,10);
#. gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);
#. gtk_box_pack_start (GTK_BOX(vbox)
#. , hbox,FALSE, FALSE, 0);
#.
#: src/pref_selection.c:230
msgid "Beep on no hit"
msgstr ""

#: src/pref_selection.c:232
msgid "Beep when no hit."
msgstr ""

#: src/pref_shortcut.c:59
msgid "Toggle Menu Mar"
msgstr ""

#: src/pref_shortcut.c:60
msgid "Toggle Status Bar"
msgstr ""

#: src/pref_shortcut.c:61
msgid "Toggle Dictionary Bar"
msgstr ""

#: src/pref_shortcut.c:62
msgid "Switch Pane Direction"
msgstr ""

#: src/pref_shortcut.c:63
msgid "Select Automatic Search"
msgstr ""

#: src/pref_shortcut.c:64
msgid "Select Exactword Search"
msgstr ""

#: src/pref_shortcut.c:65
msgid "Select Word Search"
msgstr ""

#: src/pref_shortcut.c:66
msgid "Select Endword Search"
msgstr ""

#: src/pref_shortcut.c:67
msgid "Select Keyword Search"
msgstr ""

#: src/pref_shortcut.c:68
msgid "Select Multi Search"
msgstr ""

#: src/pref_shortcut.c:69
msgid "Select Fulltext Search"
msgstr ""

#: src/pref_shortcut.c:70
msgid "Select Internet Search"
msgstr ""

#: src/pref_shortcut.c:71
msgid "Select File Search"
msgstr ""

#: src/pref_shortcut.c:72
msgid "Next Dictionary Group"
msgstr ""

#: src/pref_shortcut.c:73
msgid "Previous Dictionary Group"
msgstr ""

#: src/pref_shortcut.c:74
msgid "Toggle Dictionary No. 1"
msgstr ""

#: src/pref_shortcut.c:75
msgid "Toggle Dictionary No. 2"
msgstr ""

#: src/pref_shortcut.c:76
msgid "Toggle Dictionary No. 3"
msgstr ""

#: src/pref_shortcut.c:77
msgid "Toggle Dictionary No. 4"
msgstr ""

#: src/pref_shortcut.c:78
msgid "Toggle Dictionary No. 5"
msgstr ""

#: src/pref_shortcut.c:79
msgid "Toggle Dictionary No. 6"
msgstr ""

#: src/pref_shortcut.c:80
msgid "Toggle Dictionary No. 7"
msgstr ""

#: src/pref_shortcut.c:81
msgid "Toggle Dictionary No. 8"
msgstr ""

#: src/pref_shortcut.c:82
msgid "Toggle Dictionary No. 9"
msgstr ""

#: src/pref_shortcut.c:83
msgid "Toggle Dictionary No. 10"
msgstr ""

#: src/pref_shortcut.c:84
msgid "Next Hit"
msgstr ""

#: src/pref_shortcut.c:85
msgid "Previous Hit"
msgstr ""

#: src/pref_shortcut.c:86
msgid "Copy To Clipboard"
msgstr ""

#: src/pref_shortcut.c:87
msgid "Paste From Clipboard"
msgstr ""

#: src/pref_shortcut.c:88
msgid "Start Search"
msgstr ""

#: src/pref_shortcut.c:89
msgid "Go Back In History"
msgstr ""

#: src/pref_shortcut.c:90
msgid "Go Forward In History"
msgstr ""

#: src/pref_shortcut.c:91
msgid "Show Previous Text"
msgstr ""

#: src/pref_shortcut.c:92
msgid "Show Next Text"
msgstr ""

#. { N_("Toggle Selection Search"), toggle_auto},
#. { N_("Toggle Popup"), toggle_popup},
#: src/pref_shortcut.c:95
msgid "Show Help"
msgstr ""

#: src/pref_shortcut.c:96
msgid "Clear Word"
msgstr ""

#: src/pref_shortcut.c:97
msgid "Quit Program"
msgstr ""

#: src/pref_shortcut.c:98
msgid "Iconify Window"
msgstr ""

#: src/pref_shortcut.c:99
msgid "Scroll Mainview Down"
msgstr ""

#: src/pref_shortcut.c:100
msgid "Scroll Mainview Up"
msgstr ""

#: src/pref_shortcut.c:101
msgid "Next Hits"
msgstr ""

#: src/pref_shortcut.c:102
msgid "Prev. Hits"
msgstr ""

#: src/pref_shortcut.c:377 src/preference.c:93
msgid "Shortcut"
msgstr ""

#: src/pref_shortcut.c:400
msgid "Key"
msgstr ""

#: src/pref_shortcut.c:408 src/pref_shortcut.c:522
msgid "Command"
msgstr ""

#: src/pref_shortcut.c:464
msgid "Grab"
msgstr ""

#: src/pref_shortcut.c:540
msgid "Ignore locks"
msgstr ""

#: src/pref_shortcut.c:544
msgid "Ignore Caps Lock and Num Lock key."
msgstr ""

#: src/pref_stemming.c:166
msgid "Perform stemming"
msgstr ""

#: src/pref_stemming.c:168
msgid ""
"When ending of each words matches the pattern in the list, normal form of "
"the word will also be tried. It takes longer."
msgstr ""

#: src/pref_stemming.c:175
msgid "Stemming only when no hit"
msgstr ""

#: src/pref_stemming.c:177
msgid "Do not perform stemming when original words hit."
msgstr ""

#: src/pref_stemming.c:187
msgid "English"
msgstr ""

#: src/pref_stemming.c:190
msgid "Japanese"
msgstr ""

#: src/pref_stemming.c:211 src/pref_stemming.c:273
msgid "Pattern"
msgstr ""

#: src/pref_stemming.c:224
msgid "Correction"
msgstr ""

#: src/pref_weblist.c:352
msgid "Please specify name"
msgstr ""

#: src/pref_weblist.c:359
msgid "Please specify pre string"
msgstr ""

#: src/pref_weblist.c:428
msgid "Search engines"
msgstr ""

#: src/pref_weblist.c:519
msgid "Search engine"
msgstr ""

#: src/pref_weblist.c:545
msgid "Homepage"
msgstr ""

#: src/pref_weblist.c:555
msgid "Pre string"
msgstr ""

#: src/pref_weblist.c:565
msgid "Post string"
msgstr ""

#: src/pref_weblist.c:575
msgid "Glue string"
msgstr ""

#: src/pref_weblist.c:586
msgid "Character Code"
msgstr ""

#: src/preference.c:79
msgid "Appearance"
msgstr ""

#: src/preference.c:80
msgid "Font"
msgstr ""

#: src/preference.c:82 src/preference.c:92
msgid "Misc."
msgstr ""

#: src/preference.c:83
msgid "Dictionary Search"
msgstr ""

#: src/preference.c:84
msgid "Dictionary Group"
msgstr ""

#: src/preference.c:86
msgid "Stemming"
msgstr ""

#: src/preference.c:87
msgid "Misc"
msgstr ""

#: src/preference.c:89
msgid "Directory Group"
msgstr ""

#: src/preference.c:90
msgid "Filter"
msgstr ""

#: src/preference.c:91
msgid "Cache"
msgstr ""

#: src/preference.c:95
msgid "External Program"
msgstr ""

#: src/preference.c:573
msgid "Items"
msgstr ""

#: src/preference.c:634
msgid "Ok"
msgstr ""

#: src/render.c:869
msgid " [Movie] "
msgstr ""

#: src/splash.c:120
msgid "Loading dictionary..."
msgstr ""

#: src/textview.c:47
msgid "/Search This Word"
msgstr ""

#: src/textview.c:48
msgid "/Copy To Clipboard"
msgstr ""

#: src/textview.c:49
msgid "/Display"
msgstr ""

#: src/textview.c:50
msgid "/Display/Menu bar"
msgstr ""

#: src/textview.c:51
msgid "/Display/Dictionary Selection Bar"
msgstr ""

#: src/textview.c:52
msgid "/Display/Status Bar"
msgstr ""

#: src/textview.c:53
msgid "/Display/Tree Frame Tab"
msgstr ""

#: src/thread_search.c:61
msgid "Canceled"
msgstr ""

#: src/thread_search.c:100
msgid "Cancel"
msgstr ""

#: src/thread_search.c:106
msgid "Searching"
msgstr ""

#: src/thread_search.c:136
#, c-format
msgid "%d hit"
msgstr ""

#: src/websearch.c:42
msgid "/Go Home"
msgstr ""

#: src/websearch.c:43
msgid "/Search"
msgstr ""

#: src/websearch.c:116 src/websearch.c:178
msgid "Please select web site"
msgstr ""
